@@ -30,7 +30,7 @@ def basic_table(read_path, read_type='csv', sheet_name=None, columns_to_keep=Non
         for new_column_name, math_expression in pre_agg_math_columns.items():
             df_basic_table[new_column_name] = df_basic_table.eval(math_expression)
     
-    if filters is not None:
+    if filters is not None: ## need to add in a isin filter ability within this functionality or create a new argument for it
         for column, operator, value in filters:
             if operator == "==":
                 df_basic_table = df_basic_table[df_basic_table[column] == value]
@@ -59,7 +59,13 @@ def is_in(df, target_col, isin_list):
 def cast(df, target_col, value):
     df[target_col] = value
     return df
-    
+
+def export(file_name, tables):
+    with pd.ExcelWriter(file_name) as writer:
+        for tab_name, df_name in tables.items():
+            df_name.to_excel(writer, sheet_name=tab_name, index=False)
+    return print(f"Data written too {file_name}")
+
 def create_row(): # might not be needed, if so it will be a create row with filter and col_ops
     pass
 
